==> datanucleus-core-1.0.5-sources.jar: org/datanucleus/store/scostore/CollectionStore.java <==
/**********************************************************************
Copyright (c) 2004 Andy Jefferson and others. All rights reserved. 
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License. 
 

Contributors:
    ...
**********************************************************************/
package org.datanucleus.store.scostore;

import java.util.Collection;
import java.util.Iterator;

import org.datanucleus.StateManager;

/**
 * Interface representation of the backing store for a Collection.
 *
 * @version $Revision: 1.17 $
 **/
public interface CollectionStore extends Store
{
    // --------------------------- Accessor Methods ----------------------------
 
    /**
     * Accessor for the element type in the collection.
     * @return The element type.
     **/
    String getElementType();

    /**
     * Accessor for whether the store utilises an order mapping.
     * An order mapping is used to allow for ordering of elements or to allow duplicates.
     * @return Whether it uses an order mapping.
     */
    boolean hasOrderMapping();

    /**
     * Method to update en embedded element in the collection.
     * @param sm State Manager of the owner
     * @param element The element
     * @param fieldNumber Field to update in the element
     * @param value The new value for the field
     * @return Whether the element was modified
     */
    boolean updateEmbeddedElement(StateManager sm, Object element, int fieldNumber, Object value);

    // -------------------------- Collection Methods ---------------------------
 
    /**
     * Accessor for an iterator for the collection.
     * @param sm State Manager for the collection. 
     * @return Iterator for the collection.
     **/
    Iterator iterator(StateManager sm);

    /**
     * Accessor for the size of the collection.
     * @param sm State Manager for the collection. 
     * @return The size of the collection.
     **/
    int size(StateManager sm);

    /**
     * Method to check if an element exists in the collection.
     * @param sm State Manager for the collection. 
     * @param element Element to check
     * @return Whether the element exists in the collection.
     **/
    boolean contains(StateManager sm, Object element);

    /**
     * Method to add an element to the collection.
     * @param sm State Manager for the collection. 
     * @param element Element to add
     * @param size Current size of the collection if known. -1 if not known
     * @return Whether the element was added ok
     */
    boolean add(StateManager sm, Object element, int size);

    /**
     * Method to add a collection of elements to the collection.
     * @param sm State Manager for the collection. 
     * @param elements Elements to add
     * @param size Current size of collection (if known). -1 if not known
     * @return Whether the elements were added ok
     */
    boolean addAll(StateManager sm, Collection elements, int size);

    /**
     * Method to remove an element from the collection.
     * @param sm State Manager for the collection. 
     * @param element Element to remove
     * @param size Current size of collection if known. -1 if not known
     * @param allowDependentField Whether to allow any cascading delete actions to be fired from this removal
     * @return Whether the element was removed ok
     */
    boolean remove(StateManager sm, Object element, int size, boolean allowDependentField);

    /**
     * Method to remove a collection of elements from the collection.
     * @param sm State Manager for the collection. 
     * @param elements Element to remove
     * @param size Current size of collection if known. -1 if not known
     * @return Whether the elements were removed ok
     */
    boolean removeAll(StateManager sm, Collection elements, int size);

    /**
     * Method to clear the collection.
     * @param sm State Manager for the collection. 
     **/
    void clear(StateManager sm);
}

==> datanucleus-core-2.2.2-sources.jar: org/datanucleus/store/scostore/CollectionStore.java <==
/**********************************************************************
Copyright (c) 2004 Andy Jefferson and others. All rights reserved. 
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License. 
 

Contributors:
    ...
**********************************************************************/
package org.datanucleus.store.scostore;

import java.util.Collection;
import java.util.Iterator;

import org.datanucleus.store.ObjectProvider;

/**
 * Interface representation of the backing store for a Collection.
 */
public interface CollectionStore extends Store
{
    // --------------------------- Accessor Methods ----------------------------
 
    /**
     * Accessor for the element type in the collection.
     * @return The element type.
     **/
    String getElementType();

    /**
     * Accessor for whether the store utilises an order mapping.
     * An order mapping is used to allow for ordering of elements or to allow duplicates.
     * @return Whether it uses an order mapping.
     */
    boolean hasOrderMapping();

    /**
     * Method to update en embedded element in the collection.
     * @param sm State Manager of the owner
     * @param element The element
     * @param fieldNumber Field to update in the element
     * @param value The new value for the field
     * @return Whether the element was modified
     */
    boolean updateEmbeddedElement(ObjectProvider sm, Object element, int fieldNumber, Object value);

    // -------------------------- Collection Methods ---------------------------
 
    /**
     * Accessor for an iterator for the collection.
     * @param sm State Manager for the collection. 
     * @return Iterator for the collection.
     **/
    Iterator iterator(ObjectProvider sm);

    /**
     * Accessor for the size of the collection.
     * @param sm State Manager for the collection. 
     * @return The size of the collection.
     **/
    int size(ObjectProvider sm);

    /**
     * Method to check if an element exists in the collection.
     * @param sm State Manager for the collection. 
     * @param element Element to check
     * @return Whether the element exists in the collection.
     **/
    boolean contains(ObjectProvider sm, Object element);

    /**
     * Method to add an element to the collection.
     * @param sm State Manager for the collection. 
     * @param element Element to add
     * @param size Current size of the collection if known. -1 if not known
     * @return Whether the element was added ok
     */
    boolean add(ObjectProvider sm, Object element, int size);

    /**
     * Method to add a collection of elements to the collection.
     * @param sm State Manager for the collection. 
     * @param elements Elements to add
     * @param size Current size of collection (if known). -1 if not known
     * @return Whether the elements were added ok
     */
    boolean addAll(ObjectProvider sm, Collection elements, int size);

    /**
     * Method to remove an element from the collection.
     * @param sm State Manager for the collection. 
     * @param element Element to remove
     * @param size Current size of collection if known. -1 if not known
     * @param allowDependentField Whether to allow any cascading delete actions to be fired from this removal
     * @return Whether the element was removed ok
     */
    boolean remove(ObjectProvider sm, Object element, int size, boolean allowDependentField);

    /**
     * Method to remove a collection of elements from the collection.
     * @param sm State Manager for the collection. 
     * @param elements Element to remove
     * @param size Current size of collection if known. -1 if not known
     * @return Whether the elements were removed ok
     */
    boolean removeAll(ObjectProvider sm, Collection elements, int size);

    /**
     * Method to clear the collection.
     * @param sm State Manager for the collection. 
     **/
    void clear(ObjectProvider sm);

    /**
     * Method to update the collection to be the supplied collection of elements.
     * @param sm StateManager of the object
     * @param coll The collection to use
     */
    void update(ObjectProvider sm, Collection coll);
}
